Are you using the latest version of tmuxp? Check `tmuxp -V` against
https://pypi.org/project/tmuxp/. If it's not the latest, consider updating, e.g.
`pip install --user tmuxp`.

### Step 1: Provide a summary of your problem

- For general technical questions, problems or feature requests related to the code **in this repository** file an issue.

### Step 2: Provide tmuxp details

- Include output of `tmuxp debug-info`
- Include any other pertinant system info not captured

### Step 3: Describe the problem:

#### Steps to reproduce:

1. ...
2. ...
3. ...

#### Observed Results:

- What happened? This could be a description, log output, etc.

#### Expected Results:

- What did you expect to happen?

#### Relevant Code:

```
// TODO(you): paste here tmuxp configuration (YAML / JSON) you are having issues with.
```
